@@ -686,14 +686,22 @@ ebews_set_full_name_changes (ESoapMessage *message,
 
 	name = e_contact_get (new, E_CONTACT_NAME);
 	old_name = e_contact_get (old, E_CONTACT_NAME);
-	if (!name && !old_name)
+	if (!old_name && !name)
 		return;
 
-	if (g_strcmp0 (name->given, old_name->given) != 0)
+	if (!old_name) {
 		convert_contact_property_to_updatexml (message, "GivenName", name->given, "contacts", NULL, NULL);
-
-	if (g_strcmp0 (name->additional, old_name->additional) != 0)
 		convert_contact_property_to_updatexml (message, "MiddleName", name->additional, "contacts", NULL, NULL);
+	} else if (!name) {
+		convert_contact_property_to_updatexml (message, "GivenName", "", "contacts", NULL, NULL);
+
+		convert_contact_property_to_updatexml (message, "MiddleName", "", "contacts", NULL, NULL);
+	} else {
+		if (g_strcmp0 (name->given, old_name->given) != 0)
+			convert_contact_property_to_updatexml (message, "GivenName", name->given, "contacts", NULL, NULL);
+		if (g_strcmp0 (name->additional, old_name->additional) != 0)
+			convert_contact_property_to_updatexml (message, "MiddleName", name->additional, "contacts", NULL, NULL);
+	}
 
 	e_contact_name_free (name);
 	e_contact_name_free (old_name);
@@ -2737,7 +2745,7 @@ e_book_backend_ews_start_view (EBookBackend *backend,
 	gboolean is_autocompletion = FALSE;
 	gchar *auto_comp_str = NULL;
 	GCancellable *cancellable;
-	GSList *ids = NULL, *mailboxes = NULL, *l, *contacts = NULL, *c;
+	GSList *mailboxes = NULL, *l, *contacts = NULL, *c;
 	EwsFolderId *fid;
 	ESource *source;
 	ESourceEwsFolder *extension;
@@ -2813,7 +2821,6 @@ e_book_backend_ews_start_view (EBookBackend *backend,
 	fid = g_new0 (EwsFolderId, 1);
 	fid->id = g_strdup (priv->folder_id);
 	fid->change_key = e_source_ews_folder_dup_change_key (extension);
-	ids = g_slist_append (ids, fid);
 
 	/* We do not scan until we reach the last_item as it might be good enough to show first 100
 	 * items during auto-completion. Change it if needed. TODO, Personal Address-book should start using
