@@ -294,7 +294,6 @@ ews_update_mgtrequest_mime_calendar_itemid (const gchar *mime_fname,
 		icalcomponent *icalcomp, *subcomp;
 		icalproperty *icalprop;
 		gchar *calstring_new, *dir;
-		const gchar *temp;
 		gint fd;
 		gboolean success = FALSE;
 
@@ -335,9 +334,8 @@ ews_update_mgtrequest_mime_calendar_itemid (const gchar *mime_fname,
 		icalcomponent_free (icalcomp);
 		g_object_unref (tmpstream);
 
-		// Create a new file to store updated mimecontent
-		temp = g_strrstr (mime_fname, "/");
-		dir = g_strndup (mime_fname, temp - mime_fname);
+		/* Create a new file to store updated mimecontent */
+		dir = g_path_get_dirname (mime_fname);
 		mime_fname_new = g_build_filename ((const gchar *) dir, "XXXXXX", NULL);
 		fd = g_mkstemp (mime_fname_new);
 		if (fd == -1) {
@@ -358,10 +356,8 @@ ews_update_mgtrequest_mime_calendar_itemid (const gchar *mime_fname,
 		g_remove (mime_fname);
 		success = TRUE;
  exit_save:
-		if (fd != -1) {
+		if (fd != -1)
 			close (fd);
-			fd = -1;
-		}
 		g_free (dir);
 		if (newstream)
 			g_object_unref (newstream);
@@ -375,7 +371,6 @@ ews_update_mgtrequest_mime_calendar_itemid (const gchar *mime_fname,
  exit_parser:
 	g_object_unref (mimeparser);
 	close (fd_old);
-	fd_old = -1;
 
 	// must be freed in the caller
 	return mime_fname_new;
@@ -399,7 +394,6 @@ camel_ews_folder_get_message (CamelFolder *folder,
 	gchar *mime_dir;
 	gchar *cache_file;
 	gchar *dir;
-	const gchar *temp;
 	gboolean res;
 	gchar *mime_fname_new = NULL;
 	GError *local_error = NULL;
@@ -481,7 +475,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 		e_ews_item_get_item_type (items->data) == E_EWS_ITEM_TYPE_MEETING_MESSAGE ||
 		e_ews_item_get_item_type (items->data) == E_EWS_ITEM_TYPE_MEETING_RESPONSE) {
 		GSList *items_req = NULL;
-		const EwsId *calendar_item_accept_id;
+		const EwsId *calendar_item_accept_id = NULL;
 		gboolean is_calendar_UID = TRUE;
 
 		// Get AssociatedCalendarItemId with second get_items call
@@ -504,9 +498,12 @@ camel_ews_folder_get_message (CamelFolder *folder,
 			}
 			goto exit;
 		}
-		calendar_item_accept_id = e_ews_item_get_calendar_item_accept_id (items_req->data);
+
+		if (items_req != NULL)
+			calendar_item_accept_id = e_ews_item_get_calendar_item_accept_id (items_req->data);
+
 		/*In case of non-exchange based meetings invites the calendar backend have to create the meeting*/
-		if (!calendar_item_accept_id) {
+		if (calendar_item_accept_id == NULL) {
 			calendar_item_accept_id = e_ews_item_get_id (items->data);
 			is_calendar_UID = FALSE;
 		}
@@ -514,7 +511,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 		if (mime_fname_new)
 			mime_content = (const gchar *) mime_fname_new;
 
-		if (items_req) {
+		if (items_req != NULL) {
 			g_object_unref (items_req->data);
 			g_slist_free (items_req);
 		}
@@ -522,8 +519,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 
 	cache_file = ews_data_cache_get_filename (
 		ews_folder->cache, "cur", uid, error);
-	temp = g_strrstr (cache_file, "/");
-	dir = g_strndup (cache_file, temp - cache_file);
+	dir = g_path_get_dirname (cache_file);
 
 	if (g_mkdir_with_parents (dir, 0700) == -1) {
 		g_set_error (
@@ -922,8 +918,6 @@ ews_move_to_junk_folder (CamelFolder *folder,
 		return TRUE;
 	}
 
-	ews_store = CAMEL_EWS_STORE (camel_folder_get_parent_store (folder));
-
 	parent_store = camel_folder_get_parent_store (folder);
 	ews_folder = CAMEL_EWS_FOLDER (folder);
 	ews_store = CAMEL_EWS_STORE (parent_store);
